diff mbox

[U-Boot,2/4] dumpimage: replace the term "datafile" by "subimage"

Message ID 1421297683-6989-2-git-send-email-guilherme.maciel.ferreira@gmail.com
State Accepted
Delegated to: Tom Rini
Headers show

Commit Message

Guilherme Maciel Ferreira Jan. 15, 2015, 4:54 a.m. UTC
Signed-off-by: Guilherme Maciel Ferreira <guilherme.maciel.ferreira@gmail.com>
---
 tools/default_image.c |    6 +++---
 tools/dumpimage.c     |   12 ++++++------
 tools/imagetool.c     |    2 +-
 tools/imagetool.h     |   17 +++++++++--------
 4 files changed, 19 insertions(+), 18 deletions(-)

Comments

Tom Rini Feb. 2, 2015, 6:58 p.m. UTC | #1
On Thu, Jan 15, 2015 at 02:54:41AM -0200, Guilherme Maciel Ferreira wrote:

> Signed-off-by: Guilherme Maciel Ferreira <guilherme.maciel.ferreira@gmail.com>

Applied to u-boot/master, thanks!
diff mbox

Patch

diff --git a/tools/default_image.c b/tools/default_image.c
index 0b0e076..2298f91 100644
--- a/tools/default_image.c
+++ b/tools/default_image.c
@@ -117,7 +117,7 @@  static void image_set_header(void *ptr, struct stat *sbuf, int ifd,
 	image_set_hcrc(hdr, checksum);
 }
 
-static int image_extract_datafile(void *ptr, struct image_tool_params *params)
+static int image_extract_subimage(void *ptr, struct image_tool_params *params)
 {
 	const image_header_t *hdr = (const image_header_t *)ptr;
 	ulong file_data;
@@ -144,7 +144,7 @@  static int image_extract_datafile(void *ptr, struct image_tool_params *params)
 	}
 
 	/* save the "data file" into the file system */
-	return imagetool_save_datafile(params->outfile, file_data, file_len);
+	return imagetool_save_subimage(params->outfile, file_data, file_len);
 }
 
 /*
@@ -159,7 +159,7 @@  U_BOOT_IMAGE_TYPE(
 	image_verify_header,
 	image_print_contents,
 	image_set_header,
-	image_extract_datafile,
+	image_extract_subimage,
 	image_check_image_types,
 	NULL,
 	NULL
diff --git a/tools/dumpimage.c b/tools/dumpimage.c
index 8f1527a..75a5d47 100644
--- a/tools/dumpimage.c
+++ b/tools/dumpimage.c
@@ -18,7 +18,7 @@  static struct image_tool_params params = {
 };
 
 /*
- * dumpimage_extract_datafile -
+ * dumpimage_extract_subimage -
  *
  * It scans all registered image types,
  * verifies image_header for each supported image type
@@ -28,7 +28,7 @@  static struct image_tool_params params = {
  * returns negative if input image format does not match with any of
  * supported image types
  */
-static int dumpimage_extract_datafile(struct image_type_params *tparams,
+static int dumpimage_extract_subimage(struct image_type_params *tparams,
 		void *ptr, struct stat *sbuf)
 {
 	int retval = -1;
@@ -42,11 +42,11 @@  static int dumpimage_extract_datafile(struct image_type_params *tparams,
 		 * Extract the file from the image
 		 * if verify is successful
 		 */
-		if (tparams->extract_datafile) {
-			retval = tparams->extract_datafile(ptr, &params);
+		if (tparams->extract_subimage) {
+			retval = tparams->extract_subimage(ptr, &params);
 		} else {
 			fprintf(stderr,
-				"%s: extract_datafile undefined for %s\n",
+				"%s: extract_subimage undefined for %s\n",
 				params.cmdname, tparams->name);
 			return -2;
 		}
@@ -170,7 +170,7 @@  int main(int argc, char **argv)
 			 * Extract the data files from within the matched
 			 * image type. Returns the error code if not matched
 			 */
-			retval = dumpimage_extract_datafile(tparams, ptr,
+			retval = dumpimage_extract_subimage(tparams, ptr,
 					&sbuf);
 		} else {
 			/*
diff --git a/tools/imagetool.c b/tools/imagetool.c
index 9d2819e..148e466 100644
--- a/tools/imagetool.c
+++ b/tools/imagetool.c
@@ -66,7 +66,7 @@  int imagetool_verify_print_header(
 	return retval;
 }
 
-int imagetool_save_datafile(
+int imagetool_save_subimage(
 	const char *file_name,
 	ulong file_data,
 	ulong file_len)
diff --git a/tools/imagetool.h b/tools/imagetool.h
index 544f9db..34ff284 100644
--- a/tools/imagetool.h
+++ b/tools/imagetool.h
@@ -110,14 +110,15 @@  struct image_type_params {
 	void (*set_header) (void *, struct stat *, int,
 					struct image_tool_params *);
 	/*
-	 * This function is used by the command to retrieve a data file from
-	 * the image (i.e. dumpimage -i <image> -p <position> <data_file>).
+	 * This function is used by the command to retrieve a component
+	 * (sub-image) from the image (i.e. dumpimage -i <image> -p <position>
+	 * <sub-image-name>).
 	 * Thus the code to extract a file from an image must be put here.
 	 *
 	 * Returns 0 if the file was successfully retrieved from the image,
 	 * or a negative value on error.
 	 */
-	int (*extract_datafile) (void *, struct image_tool_params *);
+	int (*extract_subimage)(void *, struct image_tool_params *);
 	/*
 	 * Some image generation support for ex (default image type) supports
 	 * more than one type_ids, this callback function is used to check
@@ -169,18 +170,18 @@  int imagetool_verify_print_header(
 	struct image_tool_params *params);
 
 /**
  * imagetool_save_datafile - store data into a file
  * @file_name: name of the destination file
  * @file_data: data to be written
  * @file_len: the amount of data to store
  *
  * imagetool_save_datafile() store file_len bytes of data pointed by file_data
  * into the file name by file_name.
  *
  * returns:
  *     zero in case of success or a negative value if fail.
  */
-int imagetool_save_datafile(
+int imagetool_save_subimage(
 	const char *file_name,
 	ulong file_data,
 	ulong file_len);
@@ -202,7 +203,7 @@  void pbl_load_uboot(int fd, struct image_tool_params *mparams);
 		_verify_header, \
 		_print_header, \
 		_set_header, \
-		_extract_datafile, \
+		_extract_subimage, \
 		_check_image_type, \
 		_fflag_handle, \
 		_vrec_header \
@@ -215,7 +216,7 @@  void pbl_load_uboot(int fd, struct image_tool_params *mparams);
 		.verify_header = _verify_header, \
 		.print_header = _print_header, \
 		.set_header = _set_header, \
-		.extract_datafile = _extract_datafile, \
+		.extract_subimage = _extract_subimage, \
 		.check_image_type = _check_image_type, \
 		.fflag_handle = _fflag_handle, \
 		.vrec_header = _vrec_header \
@@ -169,18 +170,18 @@  int imagetool_verify_print_header(
 
 /**
- * imagetool_save_datafile - store data into a file
+ * imagetool_save_subimage - store data into a file
  * @file_name: name of the destination file
  * @file_data: data to be written
@@ -169,18 +170,18 @@  int imagetool_verify_print_header(
  * @file_len: the amount of data to store
  *
- * imagetool_save_datafile() store file_len bytes of data pointed by file_data
+ * imagetool_save_subimage() store file_len bytes of data pointed by file_data
  * into the file name by file_name.
  *